@@ -1,4 +1,5 @@
-// SPDX-FileCopyrightText: 2022-2023 Shun Sakai and Contributors
+// SPDX-FileCopyrightText: 2022 Kevin Matthes
+// SPDX-FileCopyrightText: 2022 Shun Sakai
 //
 // SPDX-License-Identifier: Apache-2.0 OR MIT
 
@@ -47,8 +48,8 @@ pub enum ExitCode {
     /// ```
     Usage = 64,
 
-    /// The input data was incorrect in some way.
-    /// This should only be used for user's data and not system files.
+    /// The input data was incorrect in some way. This should only be used for
+    /// user's data and not system files.
     ///
     /// # Examples
     ///
@@ -72,8 +73,8 @@ pub enum ExitCode {
     /// ```
     NoInput,
 
-    /// The user specified did not exist.
-    /// This might be used for mail addresses or remote logins.
+    /// The user specified did not exist. This might be used for mail addresses
+    /// or remote logins.
     ///
     /// # Examples
     ///
@@ -84,8 +85,8 @@ pub enum ExitCode {
     /// ```
     NoUser,
 
-    /// The host specified did not exist.
-    /// This is used in mail addresses or network requests.
+    /// The host specified did not exist. This is used in mail addresses or
+    /// network requests.
     ///
     /// # Examples
     ///
@@ -96,10 +97,9 @@ pub enum ExitCode {
     /// ```
     NoHost,
 
-    /// A service is unavailable.
-    /// This can occur if a support program or file does not exist.
-    /// This can also be used as a catch-all message when something you wanted
-    /// to do doesn't work, but you don't know why.
+    /// A service is unavailable. This can occur if a support program or file
+    /// does not exist. This can also be used as a catch-all message when
+    /// something you wanted to do doesn't work, but you don't know why.
     ///
     /// # Examples
     ///
@@ -110,9 +110,8 @@ pub enum ExitCode {
     /// ```
     Unavailable,
 
-    /// An internal software error has been detected.
-    /// This should be limited to non-operating system related errors if
-    /// possible.
+    /// An internal software error has been detected. This should be limited to
+    /// non-operating system related errors if possible.
     ///
     /// # Examples
     ///
@@ -123,11 +122,10 @@ pub enum ExitCode {
     /// ```
     Software,
 
-    /// An operating system error has been detected.
-    /// This is intended to be used for such things as "cannot fork", or "cannot
-    /// create pipe". It includes things like
-    /// [`getuid(2)`][getuid-2-man-url] returning a user that does not exist in
-    /// the passwd file.
+    /// An operating system error has been detected. This is intended to be used
+    /// for such things as "cannot fork", or "cannot create pipe". It includes
+    /// things like [`getuid(2)`][getuid-2-man-url] returning a user that does
+    /// not exist in the passwd file.
     ///
     /// # Examples
     ///
@@ -174,8 +172,8 @@ pub enum ExitCode {
     /// ```
     IoErr,
 
-    /// Temporary failure, indicating something that is not really an error.
-    /// For example that a mailer could not create a connection, and the request
+    /// Temporary failure, indicating something that is not really an error. For
+    /// example that a mailer could not create a connection, and the request
     /// should be reattempted later.
     ///
     /// # Examples
@@ -199,8 +197,8 @@ pub enum ExitCode {
     /// ```
     Protocol,
 
-    /// You did not have sufficient permission to perform the operation.
-    /// This is not intended for file system problems, which should use
+    /// You did not have sufficient permission to perform the operation. This is
+    /// not intended for file system problems, which should use
     /// [`NoInput`](Self::NoInput) or [`CantCreat`](Self::CantCreat), but rather
     /// for higher level permissions.
     ///
@@ -239,7 +237,7 @@ impl ExitCode {
     /// ```
     #[must_use]
     #[inline]
-    pub const fn is_success(self) -> bool {
+    pub const fn is_success(&self) -> bool {
         matches!(self, Self::Ok)
     }
 
@@ -256,7 +254,7 @@ impl ExitCode {
     /// ```
     #[must_use]
     #[inline]
-    pub const fn is_failure(self) -> bool {
+    pub const fn is_failure(&self) -> bool {
         !self.is_success()
     }
 
@@ -352,6 +350,24 @@ impl<T> From<Result<T>> for ExitCode {
     /// This method returns [`ExitCode::Ok`] if the result is [`Ok`], otherwise
     /// returns the appropriate variant of `ExitCode` contained in the [`Err`]
     /// variant.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// # use sysexits::ExitCode;
+    /// #
+    /// assert_eq!(ExitCode::from(Ok::<(), ExitCode>(())), ExitCode::Ok);
+    /// assert_eq!(ExitCode::from(Ok::<u8, ExitCode>(42)), ExitCode::Ok);
+    ///
+    /// assert_eq!(
+    ///     ExitCode::from(Err::<(), ExitCode>(ExitCode::Usage)),
+    ///     ExitCode::Usage
+    /// );
+    /// assert_eq!(
+    ///     ExitCode::from(Err::<u8, ExitCode>(ExitCode::Usage)),
+    ///     ExitCode::Usage
+    /// );
+    /// ```
     fn from(result: Result<T>) -> Self {
         result.map_or_else(|code| code, |_| Self::Ok)
     }
@@ -360,6 +376,19 @@ impl<T> From<Result<T>> for ExitCode {
 #[cfg(feature = "std")]
 impl From<std::io::Error> for ExitCode {
     /// Converts an [`Error`](std::io::Error) into an `ExitCode`.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// # use std::io::{Error, ErrorKind};
+    /// #
+    /// # use sysexits::ExitCode;
+    /// #
+    /// assert_eq!(
+    ///     ExitCode::from(Error::from(ErrorKind::NotFound)),
+    ///     ExitCode::NoInput
+    /// );
+    /// ```
     fn from(error: std::io::Error) -> Self {
         error.kind().into()
     }
@@ -368,6 +397,16 @@ impl From<std::io::Error> for ExitCode {
 #[cfg(feature = "std")]
 impl From<std::io::ErrorKind> for ExitCode {
     /// Converts an [`ErrorKind`](std::io::ErrorKind) into an `ExitCode`.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// # use std::io;
+    /// #
+    /// # use sysexits::ExitCode;
+    /// #
+    /// assert_eq!(ExitCode::from(io::ErrorKind::NotFound), ExitCode::NoInput);
+    /// ```
     fn from(kind: std::io::ErrorKind) -> Self {
         use std::io::ErrorKind;
 
